@@ -40,9 +40,9 @@
 
 /* Usefull in particular for loadshared where the full path
  * to the lib is needed */
-#define GDCM_SOURCE_DIR "/usr/obj/ports/gdcm-2.8.9/gdcm-2.8.9"
-#define GDCM_EXECUTABLE_OUTPUT_PATH "/usr/obj/ports/gdcm-2.8.9/build-amd64/bin"
-#define GDCM_LIBRARY_OUTPUT_PATH    "/usr/obj/ports/gdcm-2.8.9/build-amd64/bin"
+#define GDCM_SOURCE_DIR "/usr/obj/ports/gdcm-3.0.2/gdcm-3.0.2"
+#define GDCM_EXECUTABLE_OUTPUT_PATH "/usr/obj/ports/gdcm-3.0.2/build-sparc64/bin"
+#define GDCM_LIBRARY_OUTPUT_PATH    "/usr/obj/ports/gdcm-3.0.2/build-sparc64/bin"
 
 /* #undef GDCM_BUILD_TESTING */
 
@@ -89,8 +89,8 @@
 /* #undef GDCM_DEBUG */
 
 #define GDCM_CMAKE_INSTALL_PREFIX "/usr/local"
-#define GDCM_INSTALL_INCLUDE_DIR "include/gdcm-2.8"
-#define GDCM_INSTALL_DATA_DIR "share/gdcm-2.8"
+#define GDCM_INSTALL_INCLUDE_DIR "include/gdcm-3.0"
+#define GDCM_INSTALL_DATA_DIR "share/gdcm-3.0"
 
 /* Whether we are building shared libraries.  */
 #define GDCM_BUILD_SHARED_LIBS
@@ -115,9 +115,9 @@
 /* #undef GDCM_HAVE__STRICMP */
 /* #undef GDCM_HAVE__STRNICMP */
 /* #undef GDCM_HAVE__SNPRINTF */
-#define GDCM_HAVE_LROUND
+/* #undef GDCM_HAVE_LROUND */
 #define GDCM_HAVE_GETTIMEOFDAY
-#define GDCM_HAVE_ATOLL
+/* #undef GDCM_HAVE_ATOLL */
 #define GDCM_HAVE_JSON_OBJECT_OBJECT_GET_EX
 
 // MM: I have a feeling that if GDCM_HAVE_WCHAR_IFSTREAM, then UNICODE filename
@@ -145,11 +145,11 @@
 /* GDCM Versioning                                                          */
 
 /* Version number.  */
-#define GDCM_MAJOR_VERSION 2
-#define GDCM_MINOR_VERSION 8
-#define GDCM_BUILD_VERSION 9
-#define GDCM_VERSION "2.8.9"
-#define GDCM_API_VERSION "2.8"
+#define GDCM_MAJOR_VERSION 3
+#define GDCM_MINOR_VERSION 0
+#define GDCM_BUILD_VERSION 2
+#define GDCM_VERSION "3.0.2"
+#define GDCM_API_VERSION "3.0"
 
 /*
 #define GDCM_FILE_META_INFORMATION_VERSION "\0\1"
